Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1544)

Unified Diff: chrome/browser/jumplist_win.h

Issue 137263007: Move CancelableTaskTracker to //base/task/CancelableTaskTracker. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Move to base/task/cancelable_task_tracker* Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/icon_manager.cc ('k') | chrome/browser/jumplist_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/jumplist_win.h
diff --git a/chrome/browser/jumplist_win.h b/chrome/browser/jumplist_win.h
index 581721cef02de8b056a94b85a113b16eeea9405b..f244053964b3f1088c3b8067841a5073edf6db7d 100644
--- a/chrome/browser/jumplist_win.h
+++ b/chrome/browser/jumplist_win.h
@@ -13,11 +13,11 @@
#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
#include "base/synchronization/lock.h"
+#include "base/task/cancelable_task_tracker.h"
#include "chrome/browser/history/history_service.h"
#include "chrome/browser/history/history_types.h"
#include "chrome/browser/sessions/tab_restore_service.h"
#include "chrome/browser/sessions/tab_restore_service_observer.h"
-#include "chrome/common/cancelable_task_tracker.h"
#include "content/public/browser/browser_thread.h"
#include "third_party/skia/include/core/SkBitmap.h"
@@ -115,8 +115,8 @@ typedef std::vector<scoped_refptr<ShellLinkItem> > ShellLinkItemList;
// update it in a UI thread. To solve this problem, this class posts to a
// runnable method when it actually updates a JumpList.
//
// Note. CancelableTaskTracker is not thread safe, so we always delete JumpList
// on UI thread (the same thread it got constructed on).
class JumpList : public TabRestoreServiceObserver,
public content::NotificationObserver,
public base::RefCountedThreadSafe<
@@ -218,7 +218,7 @@ class JumpList : public TabRestoreServiceObserver,
base::WeakPtrFactory<JumpList> weak_ptr_factory_;
// Tracks FaviconService tasks.
- CancelableTaskTracker cancelable_task_tracker_;
+ base::CancelableTaskTracker cancelable_task_tracker_;
// The Profile object is used to listen for events
Profile* profile_;
@@ -247,7 +247,7 @@ class JumpList : public TabRestoreServiceObserver,
// Id of last favicon task. It's used to cancel current task if a new one
// comes in before it finishes.
- CancelableTaskTracker::TaskId task_id_;
+ base::CancelableTaskTracker::TaskId task_id_;
// Lock for most_visited_pages_, recently_closed_pages_, icon_urls_
// as they may be used by up to 3 threads.
« no previous file with comments | « chrome/browser/icon_manager.cc ('k') | chrome/browser/jumplist_win.cc » ('j') | no next file with comments »
@@ -115,8 +115,8 @@ typedef std::vector<scoped_refptr<ShellLinkItem> > ShellLinkItemList;
// runnable method when it actually updates a JumpList.
//
-// Note. CancelableTaskTracker is not thread safe, so we always delete JumpList
-// on UI thread (the same thread it got constructed on).
+// Note. base::CancelableTaskTracker is not thread safe, so we
+// always delete JumpList on UI thread (the same thread it got constructed on).
class JumpList : public TabRestoreServiceObserver,
public content::NotificationObserver,

Powered by Google App Engine
This is Rietveld 408576698